==> rc-ui-lib-0.1.59.tgz: package/lib/action-bar/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _ = _interopRequireDefault(require(".."));

describe('ActionBar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should allow to disable safe-area-inset-bottom prop', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      safeAreaInsetBottom: false
    }, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "chat-o",
      text: "\u5BA2\u670D"
    }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "cart-o",
      text: "\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "shop-o",
      text: "\u5E97\u94FA"
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('basic usage with ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "shop-o",
              text: "\u5E97\u94FA"
            }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
              type: "danger",
              text: "\u7ACB\u5373\u8D2D\u4E70"
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using badge prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D",
              badge: {
                dot: true
              }
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66",
              badge: {
                content: 5
              }
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when color prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "star",
              color: "#ff5000",
              text: "\u5E97\u94FA"
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when icon prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: /*#__PURE__*/_react().default.createElement(_icon.default, {
                name: "shop-o"
              }),
              text: "\u8D2D\u7269\u8F66"
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('when icon prop in ActionBarIcon is not isValidElement', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: 123,
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            })));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when iconClass prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              iconClass: "icon-class",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            expect(wrapper.find(_icon.default).at(0).find('icon-class')).toBeTruthy();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when iconPrefix prop in ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              iconPrefix: "my-icon",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            expect(wrapper.find(_icon.default).at(0).find('.my-icon-chat-o').exists()).toBeTruthy();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should emit click event in ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    var onClick;
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            onClick = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D",
              onClick: onClick
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            _context8.next = 4;
            return wrapper.find(_icon.default).at(0).children('.van-icon-chat-o').first().simulate('click');

          case 4:
            expect(onClick).toHaveBeenCalled();

          case 5:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when using type prop and text prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70"
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should render correctly when using icon prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66",
      icon: "shop-o"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70",
      icon: /*#__PURE__*/_react().default.createElement(_icon.default, {
        name: "chat-o"
      })
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('should render correctly when using color prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66",
      color: "red"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70",
      color: "linear-gradient(to right, #ffd01e, #ff8917)"
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('when ActionBarButton does not wrapperd by ActionBar', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement("div", null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70"
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('when ActionBarButton has children', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning"
    }, "\u52A0\u5165\u8D2D\u7269\u8F66"), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger"
    }, "\u7ACB\u5373\u8D2D\u4E70")));
    expect(wrapper.html()).toMatchSnapshot();
  });
});

==> rc-ui-lib-0.2.4.tgz: package/lib/action-bar/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function _react() {
  var data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _icon = _interopRequireDefault(require("../../icon"));

var _ = _interopRequireDefault(require(".."));

describe('ActionBar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should allow to disable safe-area-inset-bottom prop', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, {
      safeAreaInsetBottom: false
    }, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "chat-o",
      text: "\u5BA2\u670D"
    }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "cart-o",
      text: "\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
      icon: "shop-o",
      text: "\u5E97\u94FA"
    })));
    expect(wrapper.html()).toMatchSnapshot();
  });
  it('basic usage with ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "shop-o",
              text: "\u5E97\u94FA"
            }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
              type: "danger",
              text: "\u7ACB\u5373\u8D2D\u4E70"
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using badge prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D",
              badge: {
                dot: true
              }
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66",
              badge: {
                content: 5
              }
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when color prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "star",
              color: "#ff5000",
              text: "\u5E97\u94FA"
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when icon prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: /*#__PURE__*/_react().default.createElement(_icon.default, {
                name: "shop-o"
              }),
              text: "\u8D2D\u7269\u8F66"
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('when icon prop in ActionBarIcon is not isValidElement', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: 123,
              color: "#ee0a24",
              text: "\u5BA2\u670D"
            })));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when iconClass prop in ActionBarIcon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              iconClass: "icon-class",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            expect(wrapper.find(_icon.default).at(0).find('icon-class')).toBeTruthy();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when iconPrefix prop in ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              iconPrefix: "my-icon",
              text: "\u5BA2\u670D"
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            expect(wrapper.find(_icon.default).at(0).find('.my-icon-chat-o').exists()).toBeTruthy();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should emit click event in ActionBar.Icon', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    var onClick;
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            onClick = jest.fn();
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "chat-o",
              text: "\u5BA2\u670D",
              onClick: onClick
            }), /*#__PURE__*/_react().default.createElement(_.default.Icon, {
              icon: "cart-o",
              text: "\u8D2D\u7269\u8F66"
            })));
            _context8.next = 4;
            return wrapper.find(_icon.default).at(0).children('.van-icon-chat-o').first().simulate('click');

          case 4:
            expect(onClick).toHaveBeenCalled();

          case 5:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when using type prop and text prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70"
    })));
    expect(wrapper).toMatchSnapshot();
  });
  it('should render correctly when using icon prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66",
      icon: "shop-o"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70",
      icon: /*#__PURE__*/_react().default.createElement(_icon.default, {
        name: "chat-o"
      })
    })));
    expect(wrapper).toMatchSnapshot();
  });
  it('should render correctly when using color prop in ActionBarButton', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66",
      color: "red"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70",
      color: "linear-gradient(to right, #ffd01e, #ff8917)"
    })));
    expect(wrapper).toMatchSnapshot();
  });
  it('when ActionBarButton does not wrapperd by ActionBar', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement("div", null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning",
      text: "\u52A0\u5165\u8D2D\u7269\u8F66"
    }), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger",
      text: "\u7ACB\u5373\u8D2D\u4E70"
    })));
    expect(wrapper).toMatchSnapshot();
  });
  it('when ActionBarButton has children', function () {
    wrapper = (0, _enzyme().mount)( /*#__PURE__*/_react().default.createElement(_.default, null, /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "warning"
    }, "\u52A0\u5165\u8D2D\u7269\u8F66"), /*#__PURE__*/_react().default.createElement(_.default.Button, {
      type: "danger"
    }, "\u7ACB\u5373\u8D2D\u4E70")));
    expect(wrapper).toMatchSnapshot();
  });
});
